@@ -2,7 +2,7 @@ print.MFA <- function (x, file = NULL, sep = ";", ...){
     res.mfa <- x
     if (!inherits(res.mfa, "MFA")) stop("non convenient data")
     cat("**Results of the Multiple Factor Analysis (MFA)**\n\n")
-    cat("There are", nrow(res.mfa$call$X), "individuals, caracterized by",
+    cat("There are", nrow(res.mfa$call$X), "individuals, characterized by",
         ncol(res.mfa$call$X), "variables\n\n")
     cat("*Results are available in the following objects :\n\n")
     res <- array("", c(22, 2), list(1:22, c("nom", "description")))
